==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/GetPredictionTrainingResultsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.GetPredictionTrainingResultsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property hubName The name of the hub.
 * @property predictionName The name of the Prediction.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetPredictionTrainingResultsPlainArgs(
    public val hubName: String,
    public val predictionName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.GetPredictionTrainingResultsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.customerinsights.inputs.GetPredictionTrainingResultsPlainArgs =
        com.pulumi.azurenative.customerinsights.inputs.GetPredictionTrainingResultsPlainArgs.builder()
            .hubName(hubName.let({ args0 -> args0 }))
            .predictionName(predictionName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPredictionTrainingResultsPlainArgs].
 */
@PulumiTagMarker
public class GetPredictionTrainingResultsPlainArgsBuilder internal constructor() {
    private var hubName: String? = null

    private var predictionName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the hub.
     */
    @JvmName("bagpffrjwxtwnahu")
    public suspend fun hubName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hubName = mapped
    }

    /**
     * @param value The name of the Prediction.
     */
    @JvmName("qvijyoogevykxcwk")
    public suspend fun predictionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.predictionName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("bfrqqtkcddxpjudj")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetPredictionTrainingResultsPlainArgs =
        GetPredictionTrainingResultsPlainArgs(
            hubName = hubName ?: throw PulumiNullFieldException("hubName"),
            predictionName = predictionName ?: throw PulumiNullFieldException("predictionName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/GetPredictionTrainingResultsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.GetPredictionTrainingResultsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property hubName The name of the hub.
 * @property predictionName The name of the Prediction.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetPredictionTrainingResultsPlainArgs(
    public val hubName: String,
    public val predictionName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.GetPredictionTrainingResultsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.customerinsights.inputs.GetPredictionTrainingResultsPlainArgs =
        com.pulumi.azurenative.customerinsights.inputs.GetPredictionTrainingResultsPlainArgs.builder()
            .hubName(hubName.let({ args0 -> args0 }))
            .predictionName(predictionName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPredictionTrainingResultsPlainArgs].
 */
@PulumiTagMarker
public class GetPredictionTrainingResultsPlainArgsBuilder internal constructor() {
    private var hubName: String? = null

    private var predictionName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the hub.
     */
    @JvmName("yhwgeokghkbkrqmq")
    public suspend fun hubName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hubName = mapped
    }

    /**
     * @param value The name of the Prediction.
     */
    @JvmName("rsofkihljgmnfhcg")
    public suspend fun predictionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.predictionName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("wpcrpbodrqxlxdll")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetPredictionTrainingResultsPlainArgs =
        GetPredictionTrainingResultsPlainArgs(
            hubName = hubName ?: throw PulumiNullFieldException("hubName"),
            predictionName = predictionName ?: throw PulumiNullFieldException("predictionName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}
